# Configuring the Integration with Jira Service Management
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management#prerequisites)
  * [Configuration Overview](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management#configuration-overview)
  * [Step 1: Add the Integration](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management#step-1:-add-the-integration)
  * [Step 2: Configure Credentials](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management#step-2:-configure-credentials)
  * [Step 3: Configure Mappings](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management#step-3:-configure-mappings)
  * [Managing the Integration](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management#managing-the-integration)
  * [Troubleshooting](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management#troubleshooting)


Connect Jira Service Management to SAP LeanIX to enable data synchronization between the systems.
